# Supported Providers and Models

This page lists the supported providers and their available models.

## OpenAI

- GPT-3.5 Turbo
- GPT-4
- GPT-4 Turbo

## Google

- Gemini Pro
- Gemini 1.5 Pro

## Anthropic

- Claude 2
- Claude 3 Opus
- Claude 3 Sonnet
- Claude 3 Haiku

## MoonshotAI

- kimi-k2-turbo-preview
- kimi-k2-turbo-preview
- kimi-k1-8k
- kimi-k1-32k
- kimi-k1-128k

- Llama-3-8b-8192
- Llama-3-70b-8192

## Alibaba

- qwen-turbo
- qwen-plus
- qwen-max
- qwen3-coder-plus
- qwen3-coder-480b-a35b-instruct

## Z.AI

- glm-4.5
- glm-4
- glm-4v

<!-- Removed links to model_info.py files for all providers to avoid broken references. -->
